#' The 'bennu' package.
#'
#' @description Bayesian Estimation of Naloxone use Number Under-reporting
#'
#' @name bennu-package
#' @aliases bennu
#' @useDynLib bennu, .registration = TRUE
#' @import methods
#' @import Rcpp
#' @importFrom rstan sampling
#' @importFrom rstantools rstan_config
#' @importFrom RcppParallel RcppParallelLibs
#'
#' @references
#' Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.21.2. https://mc-stan.org
#'
"_PACKAGE"
